/*
 * $Id: statusled.c,v 1.7 2007/01/10 17:27:29 karljope Exp $
 *
 * Tool for controlling the status led.
 * Usage: statusled off|green|red|yellow
 *
 *
 * (C) Copyright 2002-2007, Axis Communications AB, LUND, SWEDEN
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <syslog.h>
#include "gpio.h"

#define GREEN  1
#define RED    2
#define YELLOW 3

static void usage(const char* cmd) {
	printf("usage: %s [off|green|red|yellow|flash [INTERVAL]|init [INTERVAL]|usage [INTERVAL]]\n", cmd);
}

int main(int argc, char **argv)
{
#ifndef HOST  
	int fd, color = 0;

	if (argc < 2)
	{
		usage(argv[0]);
		return 1;
	}

	openlog(argv[0], LOG_PID, LOG_USER);
	fd = open("/dev/leds", O_WRONLY);
	if (fd < 0) {
		int err_saved = errno;
		
		perror("open");
		syslog(LOG_ERR, "Failed to open device /dev/leds. %s", 
                       strerror(err_saved));
		return 1;
	}

	if (!strcmp(argv[1], "off")) color = 0;
	else if (!strcmp(argv[1], "green")) color = GREEN;
	else if (!strcmp(argv[1], "red")) color = RED;
	else if (!strcmp(argv[1], "yellow")) color = YELLOW;
	else if (!strcmp(argv[1], "flash")) {
		unsigned long interval = 300000;
		if (argc == 3){
			interval = atol(argv[2]) * 100000;
		}
		daemon(0, 0);
		while(1){
			ioctl(fd, _IO(GPIO_IOCTYPE, IO_LEDACTIVE_SET), RED);
			usleep(interval);
			ioctl(fd, _IO(GPIO_IOCTYPE, IO_LEDACTIVE_SET), 0);
			usleep(interval);
		}
	}
	else if (!strcmp(argv[1], "init") ||
		 !strcmp(argv[1], "usage")) {
		unsigned long interval = 300000;
		if (argc == 3){
			interval = atol(argv[2]) * 100000;
		}
		daemon(0, 0);
		while(1){
			ioctl(fd, _IO(GPIO_IOCTYPE, IO_LEDACTIVE_SET), GREEN);
			usleep(interval);
			ioctl(fd, _IO(GPIO_IOCTYPE, IO_LEDACTIVE_SET), 0);
			usleep(interval);
		}
	}
	else {
		usage(argv[0]);
		return 1;
	}

	ioctl(fd, _IO(GPIO_IOCTYPE, IO_LEDACTIVE_SET), color);
	close(fd);
#else
	printf("Simulating statusled %s\n", argv[1]);
#endif
	return 0;
}

